import lowRange from './lowRange';
import highRange from './highRange';
/**
 * Gets the proper range for the page number according to the number of pages to display
 * @param {object} params - parameters pagination
 * @param {number} params.page - Original page number
 * @param {number} params.totalPages - Total number of pages
 * @param {number} params.showPages - Number of pages to display in the range of pages displayed
 * @return {number[]} range of page numbers
 */

var range = function range(_ref) {
  var page = _ref.page,
      totalPages = _ref.totalPages,
      showPages = _ref.showPages;

  var _lowRange = lowRange({
    page: page,
    showPages: showPages
  });

  var _highRange = highRange({
    page: page,
    totalPages: totalPages,
    showPages: showPages
  });

  var rangeNumItems = _highRange === totalPages ? totalPages - _lowRange : showPages;
  return [].concat(Array.from(new Array(rangeNumItems), function (_, i) {
    return _lowRange + i + 1;
  }));
};

export default range;