import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import React from 'react';
import PropTypes from 'prop-types';
import AtomButton from '@s-ui/react-atom-button';
import * as pagination from './helpers/pagination';
import { isValidPage, isValidTotalPages, isValidShowPages } from './customPropTypes';
var BASE_CLASS = 'sui-MoleculePagination';
var CLASS_PREV_BUTTON_ICON = 'sui-MoleculePagination-prevButtonIcon';
var CLASS_NEXT_BUTTON_ICON = 'sui-MoleculePagination-nextButtonIcon';
var PAGE_NUMBER_HOLDER = '%{pageNumber}';

var PageButton = function PageButton(_ref) {
  var onSelectPage = _ref.onSelectPage,
      page = _ref.page,
      design = _ref.design,
      props = _objectWithoutPropertiesLoose(_ref, ["onSelectPage", "page", "design"]);

  var _onSelectPage = function _onSelectPage(e) {
    onSelectPage(e, {
      page: page
    });
  };

  return React.createElement("li", {
    className: BASE_CLASS + "-item"
  }, React.createElement(AtomButton, Object.assign({
    onClick: _onSelectPage,
    design: design
  }, props)));
};

// eslint-disable-next-line
var defaultLinkFactory = function defaultLinkFactory(_ref2) {
  var href = _ref2.href;
  return function (_ref3) {
    var children = _ref3.children,
        props = _ref3.props;
    return React.createElement("a", Object.assign({}, props, {
      href: href
    }), children);
  };
};

var defaultCreateUrl = function defaultCreateUrl(_ref4) {
  var pageNumber = _ref4.pageNumber,
      urlPattern = _ref4.urlPattern;
  return urlPattern.replace(PAGE_NUMBER_HOLDER, pageNumber);
};

var MoleculePagination = function MoleculePagination(_ref5) {
  var _ref5$onSelectNext = _ref5.onSelectNext,
      onSelectNext = _ref5$onSelectNext === void 0 ? function () {} : _ref5$onSelectNext,
      _ref5$onSelectPage = _ref5.onSelectPage,
      onSelectPage = _ref5$onSelectPage === void 0 ? function () {} : _ref5$onSelectPage,
      _ref5$onSelectPrev = _ref5.onSelectPrev,
      onSelectPrev = _ref5$onSelectPrev === void 0 ? function () {} : _ref5$onSelectPrev,
      page = _ref5.page,
      totalPages = _ref5.totalPages,
      _ref5$showPages = _ref5.showPages,
      showPages = _ref5$showPages === void 0 ? 10 : _ref5$showPages,
      _ref5$prevButtonText = _ref5.prevButtonText,
      prevButtonText = _ref5$prevButtonText === void 0 ? 'Previous' : _ref5$prevButtonText,
      PrevButtonIcon = _ref5.prevButtonIcon,
      _ref5$nextButtonText = _ref5.nextButtonText,
      nextButtonText = _ref5$nextButtonText === void 0 ? 'Next' : _ref5$nextButtonText,
      NextButtonIcon = _ref5.nextButtonIcon,
      _ref5$compressed = _ref5.compressed,
      compressed = _ref5$compressed === void 0 ? false : _ref5$compressed,
      hideDisabled = _ref5.hideDisabled,
      _ref5$selectedPageBut = _ref5.selectedPageButtonDesign,
      selectedPageButtonDesign = _ref5$selectedPageBut === void 0 ? 'solid' : _ref5$selectedPageBut,
      _ref5$nonSelectedPage = _ref5.nonSelectedPageButtonDesign,
      nonSelectedPageButtonDesign = _ref5$nonSelectedPage === void 0 ? 'flat' : _ref5$nonSelectedPage,
      _ref5$prevButtonDesig = _ref5.prevButtonDesign,
      prevButtonDesign = _ref5$prevButtonDesig === void 0 ? 'flat' : _ref5$prevButtonDesig,
      _ref5$nextButtonDesig = _ref5.nextButtonDesign,
      nextButtonDesign = _ref5$nextButtonDesig === void 0 ? 'flat' : _ref5$nextButtonDesig,
      _ref5$linkFactory = _ref5.linkFactory,
      linkFactory = _ref5$linkFactory === void 0 ? defaultLinkFactory : _ref5$linkFactory,
      _ref5$createUrl = _ref5.createUrl,
      createUrl = _ref5$createUrl === void 0 ? defaultCreateUrl : _ref5$createUrl,
      _ref5$urlPattern = _ref5.urlPattern,
      urlPattern = _ref5$urlPattern === void 0 ? '#' : _ref5$urlPattern,
      _ref5$renderLinks = _ref5.renderLinks,
      renderLinks = _ref5$renderLinks === void 0 ? false : _ref5$renderLinks;
  var paramsPagination = {
    page: page,
    totalPages: totalPages,
    showPages: showPages
  };

  var handleClickNext = function handleClickNext(e) {
    var page = pagination.nextPage(paramsPagination);
    onSelectNext(e, {
      page: page
    });
  };

  var handleClickPrev = function handleClickPrev(e) {
    var page = pagination.prevPage(paramsPagination);
    onSelectPrev(e, {
      page: page
    });
  };

  var range = pagination.range(paramsPagination);
  var nextPage = pagination.nextPage(paramsPagination);
  var prevPage = pagination.prevPage(paramsPagination);
  var isHidePrev = hideDisabled && !prevPage;
  var isHideNext = hideDisabled && !nextPage;

  var linkProps = function linkProps(pageNumber) {
    return renderLinks && {
      link: true,
      linkFactory: linkFactory({
        href: createUrl({
          pageNumber: pageNumber,
          urlPattern: urlPattern
        })
      })
    };
  };

  return React.createElement("ul", {
    className: BASE_CLASS
  }, !isHidePrev && React.createElement("li", {
    className: BASE_CLASS + "-item"
  }, React.createElement(AtomButton, Object.assign({
    onClick: handleClickPrev,
    design: prevButtonDesign,
    disabled: !prevPage
  }, linkProps(prevPage)), PrevButtonIcon && React.createElement("span", {
    className: CLASS_PREV_BUTTON_ICON
  }, React.createElement(PrevButtonIcon, null)), prevButtonText)), compressed ? React.createElement(PageButton, Object.assign({
    page: page,
    design: selectedPageButtonDesign,
    onSelectPage: onSelectPage
  }, linkProps(page)), page) : range.map(function (pageRange) {
    return React.createElement(PageButton, Object.assign({
      key: pageRange,
      page: pageRange,
      design: pageRange === page ? selectedPageButtonDesign : nonSelectedPageButtonDesign,
      onSelectPage: onSelectPage
    }, linkProps(pageRange)), pageRange);
  }), !isHideNext && React.createElement("li", {
    className: BASE_CLASS + "-item"
  }, React.createElement(AtomButton, Object.assign({
    onClick: handleClickNext,
    design: nextButtonDesign,
    disabled: !nextPage
  }, linkProps(nextPage)), nextButtonText, NextButtonIcon && React.createElement("span", {
    className: CLASS_NEXT_BUTTON_ICON
  }, React.createElement(NextButtonIcon, null)))));
};

MoleculePagination.displayName = 'MoleculePagination';
export default MoleculePagination;